<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="46"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Nie czyść listy</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="47"/>
        <source>Start playing current song</source>
        <translation>Zacznij odtwarzać bieżący utwór</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="48"/>
        <source>Pause current song</source>
        <translation>Wstrzymaj bieżący utwór</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="49"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Wstrzymaj jeśli odtwarza, odtwarzaj w przeciwnym wypadku</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="50"/>
        <source>Stop current song</source>
        <translation>Zatrzymaj bieżący utwór</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="51"/>
        <source>Display Jump to Track dialog</source>
        <translation>Wyświetl okno dialogowe Skocz do utworu</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="52"/>
        <source>Quit application</source>
        <translation>Zamknij program</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="53"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Ustaw głośność odtwarzania (np: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="54"/>
        <source>Print volume level</source>
        <translation>Wyświetl poziom głośności</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="55"/>
        <source>Mute/Restore volume</source>
        <translation>Wyłącz/Włącz dźwięk</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="56"/>
        <source>Print mute status</source>
        <translation>Wyświetl stan wyciszenia</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="57"/>
        <source>Skip forward in playlist</source>
        <translation>Przeskocz do przodu na liście odtwarzania</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="58"/>
        <source>Skip backwards in playlist</source>
        <translation>Przeskocz do tyłu na liście odtwarzania</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="59"/>
        <source>Show/hide application</source>
        <translation>Pokaż/ukryj aplikację</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="60"/>
        <source>Show main window</source>
        <translation>Pokaż okno główne</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="61"/>
        <source>Display Add File dialog</source>
        <translation>Wyświetl okno dialogowe dodawania plików</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="62"/>
        <source>Display Add Directory dialog</source>
        <translation>Wyświetl okno dialogowe dodawania katalogów</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="140"/>
        <source>Unknown command</source>
        <translation>Nieznane polecenie</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="435"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Użycie: qmmp [opcje] [pliki]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="436"/>
        <source>Options:</source>
        <translation>Opcje:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="442"/>
        <source>Start qmmp with the specified user interface</source>
        <translation>Uruchom qmmp z określonym interfejsem użytkownika</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="443"/>
        <source>List all available user interfaces</source>
        <translation>Wyświetl wszystkie dostępne interfejsy użytkownika</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="444"/>
        <source>Don&apos;t start the application</source>
        <translation>Nie uruchamiaj aplikacji</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="445"/>
        <source>Print debugging messages</source>
        <translation>Wyświetla komunikaty debugowania</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="446"/>
        <source>Display this text and exit</source>
        <translation>Wyświetla ten tekst i wychodzi</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="447"/>
        <source>Print version number and exit</source>
        <translation>Wyświetla wersję programu i wychodzi</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="449"/>
        <source>Home page: %1</source>
        <translation>Strona główna: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="450"/>
        <source>Development page: %1</source>
        <translation>Strona rozwoju: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="451"/>
        <source>Bug tracker: %1</source>
        <translation>Bugtracker: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="162"/>
        <location filename="../qmmpstarter.cpp" line="456"/>
        <source>Command Line Help</source>
        <translation>Pomoc linii poleceń</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="469"/>
        <source>QMMP version: %1</source>
        <translation>Wersja QMMP: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="470"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Skompilowane z wersją Qt: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="471"/>
        <source>Using Qt version: %1</source>
        <translation>Używana wersja Qt: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="474"/>
        <source>Qmmp Version</source>
        <translation>Wersja Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="491"/>
        <source>User Interfaces</source>
        <translation>Interfejs użytkownika</translation>
    </message>
</context>
</TS>
